==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/lt_LT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Bendrinama su jumis",
    "Shared with others" : "Bendrinama su kitais",
    "Shared by link" : "Bendrinama per nuorodą",
    "Nothing shared with you yet" : "Niekas nebendrinama",
    "Files and folders others share with you will show up here" : "Čia rodomi failai ir aplankai, kuriuos kiti bendrina su jumis",
    "Nothing shared yet" : "Kol kas nieko nebendrinama",
    "Files and folders you share will show up here" : "Čia rodomi failai ir aplankai, kuriuos bendrinate",
    "No shared links" : "Nėra bendrinamų nuorodų",
    "Files and folders you share by link will show up here" : "Jūsų bendrinami failai ir aplankai rodomi čia",
    "You can upload into this folder" : "Galite įkelti į šį aplanką",
    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
    "Invalid server URL" : "Neteisingas serverio adresas",
    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
    "Share" : "Dalintis",
    "No expiration date set" : "Dalinimosi pabaigos data yra nenustatyta",
    "Shared by" : "Bendrina",
    "Sharing" : "Dalinamasi",
    "File shares" : "Bendrinami duomenys",
    "Downloaded via public link" : "Atsiųsti per viešą nuorodą",
    "Downloaded by {email}" : "Parsisiųsta į {email}",
    "{file} downloaded via public link" : "{file} parsisiųsta per nuorodą",
    "{email} downloaded {file}" : "{email} atsisiuntė {file}",
    "Shared with group {group}" : "Bendrinama su grupe {group}",
    "Removed share for group {group}" : "Nebesidalinama su grupe: {group}",
    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
    "{actor} removed share for group {group}" : "{actor} nustojo dalintis su {group} grupe",
    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
    "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
    "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
    "Shared as public link" : "Bendrinama kaip viešoji nuoroda",
    "Removed public link" : "Pašalinti viešą nuorodą",
    "Public link expired" : "Pasibaigė nuorodos galiojimo laikas",
    "{actor} shared as public link" : "{actor} pradėjo bendrinti kaip viešąją nuorodą",
    "{actor} removed public link" : "{actor} pašalino nuorodą",
    "Public link of {actor} expired" : "Pasibaigė nuorodos, priklausančios {actor}, galiojimo laikas",
    "You shared {file} as public link" : "Jūs pradėjote bendrinti {file} kaip viešąją nuorodą",
    "You removed public link for {file}" : "Jūs pašalinote viešą {file} nuorodą",
    "Public link expired for {file}" : "Pasibaigė nuorodos galiojimo laikas skirtas {file}",
    "{actor} shared {file} as public link" : "{actor} pradėjo bendrinti {file} kaip viešąją nuorodą",
    "{actor} removed public link for {file}" : "{actor} nebesidalina \"{file}\"",
    "Public link of {actor} for {file} expired" : "Pasibaigė nuorodos galiojimo laikas duomenims {file}, bendrintiems {actor}",
    "{user} accepted the remote share" : "{user} priėmė bendrinamus duomenis",
    "{user} declined the remote share" : "{user} atmetė duomenų dalinimąsi",
    "You received a new remote share {file} from {user}" : "Jūs gavote naują duomenis \"{file}\" iš kito serverio nuo {user}",
    "{user} accepted the remote share of {file}" : "{user} priėmė bendrinamus duomenis \"{file}\"",
    "{user} declined the remote share of {file}" : "{user} atmetė duomenų \"{file}\" dalinimąsį",
    "{user} unshared {file} from you" : "{user} nustojo bendrinti su jumis {file}",
    "Shared with {user}" : "Pradėta bendrinti su {user}",
    "Removed share for {user}" : "Nustota dalintis su {user}",
    "{actor} shared with {user}" : "{actor} pradėjo bendrinti su {user}",
    "{actor} removed share for {user}" : "{actor} nustojo dalintis su {user}",
    "Shared by {actor}" : "Pasidalinta {actor}",
    "{actor} removed share" : "{actor} nustojo dalintis",
    "You shared {file} with {user}" : "Pasidalinote {file} su {user}",
    "You removed {user} from {file}" : "Nebesidalinate {file} su {user}",
    "{actor} shared {file} with {user}" : "{actor} pasidalino {file} su {user}",
    "{actor} removed {user} from {file}" : "{actor} nebesidalina {file} su {user}",
    "{actor} shared {file} with you" : "{actor} pasidalino {file} su jumis",
    "{actor} removed you from {file}" : "{actor} nebesidalina su jumis {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Duomenys, bendrinti per elektroninį paštą, buvo <strong>parsiųsti</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pasidalintas iš <strong>kito serverio</strong>",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas buvo <strong>pasidalintas</strong>",
    "Wrong share ID, share doesn't exist" : "Neteisingas dalinamų duomenų ID",
    "could not delete share" : "nepavyko nustoti dalintis duomenimis",
    "Could not delete share" : "Nepavyko nustoti dalintis duomenimis",
    "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
    "Wrong path, file/folder doesn't exist" : "Neteisingas kelias, failo/aplanko nėra",
    "Could not create share" : "Negalima dalintis",
    "invalid permissions" : "neteisingi leidimai",
    "Please specify a valid user" : "Nurodykite naudotoją",
    "Group sharing is disabled by the administrator" : "Bendrinimas su grupėmis yra išjungtas",
    "Please specify a valid group" : "Nurodykite grupę",
    "Public link sharing is disabled by the administrator" : "Dalinimasis per nuorodą yra išjungtas",
    "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
    "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkamas datos formavimas. Privaloma: YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "%s dalinimasis nepavyko, nes sistema nepalaiko šio duomenų tipo: %s",
    "You cannot share to a Circle if the app is not enabled" : "Negalite dalintis su naudotojų ratu, kai įskiepis \"Circle\" neveikia",
    "Please specify a valid circle" : "Pasirinkite naudotojų ratą",
    "Unknown share type" : "Nežinomas bendrinamų duomenų tipas",
    "Not a directory" : "Nėra katalogas",
    "Could not lock path" : "Nepavyko užrakinti kelio",
    "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
    "Can't change permissions for public share links" : "Negalima keisti leidimų viešai bendrinamoms nuorodoms",
    "Cannot increase permissions" : "Negalima pridėti papildomų leidimų",
    "%s is publicly shared" : "%s yra bendrinamas viešai",
    "Share API is disabled" : "Bendrinimo API yra išjungtas",
    "File sharing" : "Duomenų dalinimasis",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "No entries found in this folder" : "Šiame aplanke įrašų nerasta",
    "Name" : "Pavadinimas",
    "Share time" : "Dalijimosi laikas",
    "Expiration date" : "Galiojimo data",
    "Sorry, this link doesn’t seem to work anymore." : "Nuoroda yra neveiksni.",
    "Reasons might be:" : "Galimos priežastys:",
    "the item was removed" : "elementas buvo pašalintas",
    "the link expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more info, please ask the person who sent this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "shared by %s" : "pasidalino %s",
    "Add to your Nextcloud" : "Pridėti į jūsų NextCloud",
    "Download" : "Atsisiųsti",
    "Download %s" : "Atsisiųsti %s",
    "Direct link" : "Tiesioginė nuoroda",
    "Upload files to %s" : "Įkelti duomenis į %s",
    "Select or drop files" : "Pasirinkite arba vilkite failus",
    "Uploading files…" : "Įkeliami failai…",
    "Uploaded files:" : "Įkelti failai:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");

==> nextcloud-12.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/lt_LT.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Bendrinama su jumis",
    "Shared with others" : "Bendrinama su kitais",
    "Shared by link" : "Bendrinama per nuorodą",
    "Nothing shared with you yet" : "Niekas nebendrinama",
    "Files and folders others share with you will show up here" : "Čia rodomi failai ir aplankai, kuriuos kiti bendrina su jumis",
    "Nothing shared yet" : "Kol kas nieko nebendrinama",
    "Files and folders you share will show up here" : "Čia rodomi failai ir aplankai, kuriuos bendrinate",
    "No shared links" : "Nėra bendrinamų nuorodų",
    "Files and folders you share by link will show up here" : "Jūsų bendrinami failai ir aplankai rodomi čia",
    "You can upload into this folder" : "Galite įkelti į šį aplanką",
    "No compatible server found at {remote}" : "Nerasta jokio suderinamo serverio ties {remote}",
    "Invalid server URL" : "Neteisingas serverio adresas",
    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
    "Share" : "Dalintis",
    "No expiration date set" : "Dalinimosi pabaigos data yra nenustatyta",
    "Shared by" : "Bendrina",
    "Sharing" : "Dalinamasi",
    "File shares" : "Bendrinami duomenys",
    "Downloaded via public link" : "Atsiųsti per viešą nuorodą",
    "Downloaded by {email}" : "Parsisiųsta į {email}",
    "{file} downloaded via public link" : "{file} parsisiųsta per nuorodą",
    "{email} downloaded {file}" : "{email} atsisiuntė {file}",
    "Shared with group {group}" : "Bendrinama su grupe {group}",
    "Removed share for group {group}" : "Nebesidalinama su grupe: {group}",
    "{actor} shared with group {group}" : "{actor} pradėjo bendrinti su grupe {group}",
    "{actor} removed share for group {group}" : "{actor} nustojo dalintis su {group} grupe",
    "You shared {file} with group {group}" : "Jūs pradėjote bendrinti {file} su grupe {group}",
    "You removed group {group} from {file}" : "Pašalinote grupę {group} iš {file}",
    "{actor} shared {file} with group {group}" : "{actor} pradėjo bendrinti {file} su grupe {group}",
    "{actor} removed group {group} from {file}" : "{actor} pašalino grupę {group} iš {file}",
    "Shared as public link" : "Bendrinama kaip viešoji nuoroda",
    "Removed public link" : "Pašalinti viešą nuorodą",
    "Public link expired" : "Pasibaigė nuorodos galiojimo laikas",
    "{actor} shared as public link" : "{actor} pradėjo bendrinti kaip viešąją nuorodą",
    "{actor} removed public link" : "{actor} pašalino nuorodą",
    "Public link of {actor} expired" : "Pasibaigė nuorodos, priklausančios {actor}, galiojimo laikas",
    "You shared {file} as public link" : "Jūs pradėjote bendrinti {file} kaip viešąją nuorodą",
    "You removed public link for {file}" : "Jūs pašalinote viešą {file} nuorodą",
    "Public link expired for {file}" : "Pasibaigė nuorodos galiojimo laikas skirtas {file}",
    "{actor} shared {file} as public link" : "{actor} pradėjo bendrinti {file} kaip viešąją nuorodą",
    "{actor} removed public link for {file}" : "{actor} nebesidalina \"{file}\"",
    "Public link of {actor} for {file} expired" : "Pasibaigė nuorodos galiojimo laikas duomenims {file}, bendrintiems {actor}",
    "{user} accepted the remote share" : "{user} priėmė bendrinamus duomenis",
    "{user} declined the remote share" : "{user} atmetė duomenų dalinimąsi",
    "You received a new remote share {file} from {user}" : "Jūs gavote naują duomenis \"{file}\" iš kito serverio nuo {user}",
    "{user} accepted the remote share of {file}" : "{user} priėmė bendrinamus duomenis \"{file}\"",
    "{user} declined the remote share of {file}" : "{user} atmetė duomenų \"{file}\" dalinimąsį",
    "{user} unshared {file} from you" : "{user} nustojo bendrinti su jumis {file}",
    "Shared with {user}" : "Pradėta bendrinti su {user}",
    "Removed share for {user}" : "Nustota dalintis su {user}",
    "{actor} shared with {user}" : "{actor} pradėjo bendrinti su {user}",
    "{actor} removed share for {user}" : "{actor} nustojo dalintis su {user}",
    "Shared by {actor}" : "Pasidalinta {actor}",
    "{actor} removed share" : "{actor} nustojo dalintis",
    "You shared {file} with {user}" : "Pasidalinote {file} su {user}",
    "You removed {user} from {file}" : "Nebesidalinate {file} su {user}",
    "{actor} shared {file} with {user}" : "{actor} pasidalino {file} su {user}",
    "{actor} removed {user} from {file}" : "{actor} nebesidalina {file} su {user}",
    "{actor} shared {file} with you" : "{actor} pasidalino {file} su jumis",
    "{actor} removed you from {file}" : "{actor} nebesidalina su jumis {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "Duomenys, bendrinti per elektroninį paštą, buvo <strong>parsiųsti</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "Failas ar aplankas buvo pasidalintas iš <strong>kito serverio</strong>",
    "A file or folder has been <strong>shared</strong>" : "Failas ar aplankas buvo <strong>pasidalintas</strong>",
    "Wrong share ID, share doesn't exist" : "Neteisingas dalinamų duomenų ID",
    "could not delete share" : "nepavyko nustoti dalintis duomenimis",
    "Could not delete share" : "Nepavyko nustoti dalintis duomenimis",
    "Please specify a file or folder path" : "Nurodykite kelią iki duomenų",
    "Wrong path, file/folder doesn't exist" : "Neteisingas kelias, failo/aplanko nėra",
    "Could not create share" : "Negalima dalintis",
    "invalid permissions" : "neteisingi leidimai",
    "Please specify a valid user" : "Nurodykite naudotoją",
    "Group sharing is disabled by the administrator" : "Bendrinimas su grupėmis yra išjungtas",
    "Please specify a valid group" : "Nurodykite grupę",
    "Public link sharing is disabled by the administrator" : "Dalinimasis per nuorodą yra išjungtas",
    "Public upload disabled by the administrator" : "Įkėlimas viešam naudojimui yra išjungtas",
    "Public upload is only possible for publicly shared folders" : "Duomenų įkėlimas viešam naudojimui galimas tik į viešai dalinamus aplankus",
    "Invalid date, date format must be YYYY-MM-DD" : "Netinkamas datos formavimas. Privaloma: YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "%s dalinimasis nepavyko, nes sistema nepalaiko šio duomenų tipo: %s",
    "You cannot share to a Circle if the app is not enabled" : "Negalite dalintis su naudotojų ratu, kai įskiepis \"Circle\" neveikia",
    "Please specify a valid circle" : "Pasirinkite naudotojų ratą",
    "Unknown share type" : "Nežinomas bendrinamų duomenų tipas",
    "Not a directory" : "Nėra katalogas",
    "Could not lock path" : "Nepavyko užrakinti kelio",
    "Wrong or no update parameter given" : "Neperduoti atnaujinimo parametrai",
    "Can't change permissions for public share links" : "Negalima keisti leidimų viešai bendrinamoms nuorodoms",
    "Cannot increase permissions" : "Negalima pridėti papildomų leidimų",
    "Share API is disabled" : "Bendrinimo API yra išjungtas",
    "This share is password-protected" : "Turinys apsaugotas slaptažodžiu",
    "The password is wrong. Try again." : "Slaptažodis neteisingas. Bandykite dar kartą.",
    "Password" : "Slaptažodis",
    "No entries found in this folder" : "Šiame aplanke įrašų nerasta",
    "Name" : "Pavadinimas",
    "Share time" : "Dalijimosi laikas",
    "Expiration date" : "Galiojimo data",
    "Sorry, this link doesn’t seem to work anymore." : "Nuoroda yra neveiksni.",
    "Reasons might be:" : "Galimos priežastys:",
    "the item was removed" : "elementas buvo pašalintas",
    "the link expired" : "baigėsi nuorodos galiojimo laikas",
    "sharing is disabled" : "dalinimasis yra išjungtas",
    "For more info, please ask the person who sent this link." : "Dėl tikslesnės informacijos susisiekite su asmeniu atsiuntusiu nuorodą.",
    "shared by %s" : "pasidalino %s",
    "Download" : "Atsisiųsti",
    "Direct link" : "Tiesioginė nuoroda",
    "Add to your Nextcloud" : "Pridėti į jūsų NextCloud",
    "Download %s" : "Atsisiųsti %s",
    "Upload files to %s" : "Įkelti duomenis į %s",
    "Select or drop files" : "Pasirinkite arba vilkite failus",
    "Uploading files…" : "Įkeliami failai…",
    "Uploaded files:" : "Įkelti failai:",
    "%s is publicly shared" : "%s yra bendrinamas viešai"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
